#
# spec file for package k3b
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without lang
%bcond_without ffmpeg
%bcond_without lame
%bcond_without mad
Name:           k3b
Version:        20.04.2
Release:        bp153.2.13
Summary:        CD/DVD/Blu-ray Burning Application for KDE
License:        GPL-2.0-or-later
Group:          Productivity/Multimedia/CD/Record
URL:            https://www.kde.org
Source:         https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz
# PATCH-FIX-OPENSUSE
Patch1:         Don-t-suggest-to-install-libburn.patch
# PATCH-FIX-OPENSUSE
Patch2:         0001-Revert-Enable-the-k3b-helper-by-default.patch
# PATCH-FIX-OPENSUSE
Patch3:         fix-taglib-include-dirs.patch
BuildRequires:  extra-cmake-modules
BuildRequires:  fdupes
BuildRequires:  flac-devel
BuildRequires:  libdvdread-devel
BuildRequires:  libmpcdec-devel
BuildRequires:  libmusicbrainz-devel
BuildRequires:  libsamplerate-devel
BuildRequires:  libsndfile-devel
BuildRequires:  libvorbis-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  cmake(KF5Archive) >= 5.21.0
BuildRequires:  cmake(KF5Cddb)
BuildRequires:  cmake(KF5Config) >= 5.21.0
BuildRequires:  cmake(KF5CoreAddons) >= 5.21.0
BuildRequires:  cmake(KF5DocTools) >= 5.21.0
BuildRequires:  cmake(KF5FileMetaData) >= 5.21.0
BuildRequires:  cmake(KF5I18n) >= 5.21.0
BuildRequires:  cmake(KF5IconThemes) >= 5.21.0
BuildRequires:  cmake(KF5JobWidgets) >= 5.21.0
BuildRequires:  cmake(KF5KCMUtils) >= 5.21.0
BuildRequires:  cmake(KF5KIO) >= 5.21.0
BuildRequires:  cmake(KF5NewStuff) >= 5.21.0
BuildRequires:  cmake(KF5Notifications) >= 5.21.0
BuildRequires:  cmake(KF5NotifyConfig) >= 5.21.0
BuildRequires:  cmake(KF5Service) >= 5.21.0
BuildRequires:  cmake(KF5Solid) >= 5.21.0
BuildRequires:  cmake(KF5WidgetsAddons) >= 5.21.0
BuildRequires:  cmake(KF5XmlGui) >= 5.21.0
BuildRequires:  cmake(Qt5Core) >= 5.5.0
BuildRequires:  cmake(Qt5DBus) >= 5.5.0
BuildRequires:  cmake(Qt5Gui) >= 5.5.0
BuildRequires:  cmake(Qt5Test) >= 5.5.0
BuildRequires:  pkgconfig(taglib)
Requires:       %{_bindir}/cdrdao
Requires:       %{_bindir}/cdrecord
Requires:       %{_bindir}/mkisofs
Requires:       %{_bindir}/readcd
Requires:       dvd+rw-tools
Requires(post): hicolor-icon-theme
Requires(post): shared-mime-info
Requires(postun): hicolor-icon-theme
Requires(postun): shared-mime-info
Recommends:     %{_bindir}/normalize
Recommends:     %{_bindir}/sox
Recommends:     %{_bindir}/transcode
Recommends:     %{name}-lang
Recommends:     vcdimager
Provides:       kde4-k3b = 4.2.2.svn951754
Obsoletes:      k3b-codecs
Obsoletes:      kde4-k3b < 4.2.2.svn951754
%if %{with lang}
Source1:        https://download.kde.org/stable/release-service/%{version}/src/%{name}-%{version}.tar.xz.sig
Source2:        applications.keyring
%endif
%if %{with ffmpeg}
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavformat)
%endif
%if %{with lame}
BuildRequires:  libmp3lame-devel
Requires:       lame
%endif
%if %{with mad}
BuildRequires:  pkgconfig(mad)
%endif

%description
Featuring a graphical interface, k3b provides various
options for burning a CD, DVD, or BD (Blu-ray disc). Various types of
projects are supported, including audio and data, video
projects for DVD and VCD, as well as multi-session and mixed-mode discs. k3b
has the ability to erase re-writeable media, and can perform more
complicated tasks such as audiovisual encoding and decoding.

%package devel
Summary:        Development files for k3b
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}

%description devel
This package contain files needed for development with k3b.

%lang_package

%prep
%setup -q
%autopatch -p1

%build
CXXFLAGS="%{optflags} -fno-strict-aliasing"
%cmake_kf5 -d build -- -DBUILD_TESTING=ON -DKF5_INCLUDE_INSTALL_DIR=%{_kf5_includedir}
%cmake_build

%install
%kf5_makeinstall -C build
%if %{with lang}
  %find_lang %{name} --with-man --all-name
  %{kf5_find_htmldocs}
%endif

%suse_update_desktop_file -r org.kde.k3b Qt KDE AudioVideo DiscBurning

%fdupes -s %{buildroot}

%post
/sbin/ldconfig
%desktop_database_post
%icon_theme_cache_post

%postun
/sbin/ldconfig
%desktop_database_postun
%icon_theme_cache_postun

%files
%license COPYING*
%doc ChangeLog FAQ.txt PERMISSIONS.txt README.txt
%{_kf5_knsrcfilesdir}/k3btheme.knsrc
%dir %{_kf5_servicesdir}/ServiceMenus
%dir %{_kf5_sharedir}/konqsidebartng
%dir %{_kf5_sharedir}/konqsidebartng/virtual_folders
%dir %{_kf5_sharedir}/konqsidebartng/virtual_folders/services
%dir %{_kf5_sharedir}/solid
%dir %{_kf5_sharedir}/solid/actions
%doc %lang(en) %{_kf5_htmldir}/en/k3b/
%{_kf5_applicationsdir}/org.kde.k3b.desktop
%{_kf5_appstreamdir}/org.kde.k3b.appdata.xml
%{_kf5_bindir}/k3b
%{_kf5_iconsdir}/hicolor/*/apps/k3b.*
%{_kf5_iconsdir}/hicolor/*/mimetypes/application-x-k3b.*
%{_kf5_kxmlguidir}/k3b
%{_kf5_libdir}/libk3bdevice.so.*
%{_kf5_libdir}/libk3blib.so.*
%{_kf5_notifydir}/k3b.notifyrc
%{_kf5_plugindir}/k3b*.so
%{_kf5_plugindir}/kcm_k3b*.so
%dir %{_kf5_plugindir}/kf5/
%dir %{_kf5_plugindir}/kf5/kio/
%{_kf5_plugindir}/kf5/kio/videodvd.so
%{_kf5_servicesdir}/ServiceMenus/k3b_*.desktop
%{_kf5_servicesdir}/k3b*.desktop
%{_kf5_servicesdir}/kcm_k3b*.desktop
%{_kf5_servicesdir}/videodvd.protocol
%{_kf5_servicetypesdir}/k3bplugin.desktop
%{_kf5_sharedir}/k3b
%{_kf5_sharedir}/konqsidebartng/virtual_folders/services/videodvd.desktop
%{_kf5_sharedir}/mime/packages/x-k3b.xml
%{_kf5_sharedir}/solid/actions/k3b_*.desktop

%files devel
%license COPYING*
%{_includedir}/k3b*.h
%{_kf5_libdir}/libk3bdevice.so
%{_kf5_libdir}/libk3blib.so

%if %{with lang}
%files lang -f %{name}.lang
%license COPYING*
%endif

%changelog
* Fri Feb 19 2021 Antonio Larrosa <alarrosa@suse.com>
- Add patch to fix Taglib's cmake variables which, in KF5 5.76's
  extra-cmake-modules are named differently:
  * fix-taglib-include-dirs.patch
* Tue Jun  9 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 20.04.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-06-apps-update
- No code change since 20.04.1
* Fri May 15 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.1
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-05-apps-update
- Changes since 20.04.0:
  * Fix k3b not finishing if started without splash screen (kde#419105)
* Thu Apr 23 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.04.0
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-04-apps-update
- Changes since 20.03.90:
  * Fix k3b not finishing if started without splash screen (kde#419105)
* Sun Apr  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.90
  * New feature release
- No code change since 20.03.80
* Sun Mar 22 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 20.03.80
  * New feature release
- Too many changes to list here.
* Thu Mar  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.3
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-03-apps-update
- Changes since 19.12.2:
  * appdata: use canonical cdn screenshot location
  * Fix libsoundfiledecoder with files with non whole second length (kde#418079)
  * K3bFFMpegFile: Support files with more than one stream
  * Fix color of tracks in Media Info (kde#389428)
  * Accept WAV files in K3bLibsndfileDecoderFactory::canDecode (kde#399056)
* Fri Feb  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Replace %%make_jobs with %%cmake_build.
* Wed Feb  5 2020 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.2
  * New bugfix release
  * For more details please see:
  * https://kde.org/announcements/releases/2020-02-apps-update
- Changes since 19.12.1:
  * Accept WAV files in K3bLibsndfileDecoderFactory::canDecode (kde#399056)
  * Fix adding multiple symlinks to a data project (kde#416487)
* Tue Jan  7 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12.1
- Changes since 19.12.0:
  * Update Appstream for new release
* Tue Dec 10 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/releases/19.12
- Changes since 19.11.90:
  * Update Appstream for new release
* Sat Nov 30 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/releases/19.12-rc
- Changes since 19.11.80:
  * Link to Qt5::Xml explicitly, the code uses QDomDocument.
* Sun Nov 24 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.11.80
  * New feature release
- Changes since 19.08.3:
  * kns: install knsrc file in the new recommended location (kde#409502)
  * Replace deprecated methods
  * Minor spelling and grammar fixes.
  * Port some deprecated methods
  * expose version to cmake
  * Helper: Link to AuthCore instead of Auth
* Thu Nov  7 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.3.php
- Changes since 19.08.2:
  * Fix crash on exit while uninstalling a theme (kde#413278)
* Fri Oct 11 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.2.php
- Changes since 19.08.1:
  * Fix crash when adding big files and mkisofs is not installed (kde#411969)
  * Add DesktopEntry to notifyrc
* Thu Sep  5 2019 Luca Beltrame <lbeltrame@kde.org>
- Update to 19.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.1.php
- Changes since 19.08.0:
  * Fix taglib includes to match the way taglib was meant to be used: #include <tag.h>
* Fri Aug  9 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 19.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08.0.php
- No code change since 19.07.90
* Tue Aug  6 2019 lbeltrame@kde.org
- Update to 19.07.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-rc.php
- No code changes since 19.07.80
* Tue Jul 23 2019 lbeltrame@kde.org
- Update to 19.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.08-beta.php
- Changes since 19.04.3:
  * Use lambda instead of QSignalMapper
  * stick to one category
  * Fix no Elapsed time information issue after finished job.. (kde#405994)
  * Enable the k3b helper by default
  * Connect to result and not statusChanged
  * KAuth needs the return type to be ActionReply
  * Permission helpers: Start the jobs, otherwise this is a noop
  * Remove useless if
  * Remove ENABLE_PERMISSION_HELPER use guarding slots
- Add downstream patch to disable the KAuth helper:
  * 0001-Revert-Enable-the-k3b-helper-by-default.patch
* Sat Jul 13 2019 lbeltrame@kde.org
- Update to 19.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.3.php
- Changes since 19.04.2:
  * Avoid leaking of file descriptors to child processes
  * Fix detection of recommendation about DAO mode from growisofs
  * Fix available writing modes when formatting DVD-RW
* Fri Jun  7 2019 lbeltrame@kde.org
- Update to 19.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.2.php
- No code changes since 19.04.1
* Fri May 10 2019 lbeltrame@kde.org
- Update to 19.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.1.php
- Changes since 19.04.0:
  * Fix running the tests with CMAKE_RUNTIME_OUTPUT_DIRECTORY set
* Sat Apr 20 2019 lbeltrame@kde.org
- Update to 19.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-19.04.0.php
- No code changes since 19.03.90
* Tue Apr  9 2019 lbeltrame@kde.org
- Update to 19.03.90
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-rc.php
- Changes since 19.03.80:
  * No code changes since 19.03.80
* Wed Mar 27 2019 lbeltrame@kde.org
- Update to 19.03.80
  * New feature release
  * For more details please see:
  * https://kde.org/announcements/announce-applications-19.04-beta.php
- Changes since 18.12.3:
  * Too many changes to list here
* Sat Mar  9 2019 lbeltrame@kde.org
- Update to 18.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.3.php
- Changes since 18.12.2:
  * No code changes since 18.12.2
* Sat Feb  9 2019 lbeltrame@kde.org
- Update to 18.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.2.php
- Changes since 18.12.1:
  * No code changes since 18.12.1
* Fri Jan 11 2019 lbeltrame@kde.org
- Update to 18.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.1.php
- Changes since 18.12.0:
  * No code changes since 18.12.0
* Fri Dec 14 2018 lbeltrame@kde.org
- Update to 18.12.0
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12.0.php
- Changes since 18.11.90:
  * No code changes since 18.11.90
* Mon Dec  3 2018 lbeltrame@kde.org
- Update to 18.11.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-rc.php
- Changes since 18.11.80:
  * No code changes since 18.11.80
* Tue Nov 20 2018 Luca Beltrame <lbeltrame@kde.org>
- Run spec-cleaner
* Tue Nov 20 2018 lbeltrame@kde.org
- Update to 18.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.12-beta.php
- Changes since 18.08.3:
  * Refine appdata urls
  * Make the color of normalPen in FillStatusDisplayWidget desktop environment independent
  * Fix minor EBN issues
* Thu Nov  8 2018 lbeltrame@kde.org
- Update to 18.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.3.php
- Changes since 18.08.2:
  * MetaItemModel: Fix Qt assertion in adding rows (kde#399753)
* Thu Oct 11 2018 lbeltrame@kde.org
- Update to 18.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.2.php
- Changes since 18.08.1:
  * None
* Thu Sep  6 2018 lbeltrame@kde.org
- Update to 18.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.1.php
- Changes since 18.08.0:
  * None
* Thu Aug 16 2018 christophe@krop.fr
- Update to 18.08.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08.0.php
- Changes since 18.07.80:
  * None
* Thu Jul 26 2018 lbeltrame@kde.org
- Update to 18.07.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.08-beta.php
- Changes since 18.04.3:
  * Update changelog for 18.04 release.
  * [plugins] K3b FFMpeg Decoder Plugin Fix (kde#386105)
  * Fix heap-use-after-free issue for ThemeManager (kde#390878)
  * There is k3bfuzzertest to test QFile::encodeName and  QString::fromRawData using libFuzzer, it might be duplicate of QTBUG-57553
* Fri Jul 13 2018 lbeltrame@kde.org
- Update to 18.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.3.php
- Changes since 18.04.2:
  * None
* Fri Jun  8 2018 lbeltrame@kde.org
- Update to 18.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.2.php
- Changes since 18.04.1:
  * None
* Fri May 11 2018 lbeltrame@kde.org
- Update to 18.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.1.php
- Changes since 18.04.0:
  * Fix build with KIO < 5.33
  * Fix pixmap scaling on HiDPI screens (kde#390081)
- Dropped patches, now upstream:
  * fix-build-with-older-kio.patch
* Wed Apr 18 2018 lbeltrame@kde.org
- Update to 18.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04.0.php
- Changes since 18.03.90:
  * None
* Fri Apr  6 2018 lbeltrame@kde.org
- Update to 18.03.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-18.04-rc.php
- Changes since 17.12.3:
  * Add Foreground color for DiskInfoView's infokey and infovalue. (kde#389428)
  * Change default save path to $HOME/Videos or fallback $HOME instead of /tmp or /var/tmp (kde#385367)
  * Workaround for parsing mkisofs progress when perStr is not digit (kde#384750)
  * Fix potential null passed to a callee that requires a non-null argument. (kde#387298)
  * Fix Memory-leak issue detected by clang analyzer long time ago
  * Workaround for fixing segfault. (kde#386983)
  * Update fuzzer testcase for QFile and QString.
  * Use Address and Undefined Behaviour Sanitizer to debug.
  * Fix unnecessary spaces at the end of files names during audio cd extraction. (kde#387087)
  * Add UpdateLater event for ViewColumnAdjuster. (kde#387054)
  * Add 10px for WelcomeWidget's infoText width. (kde#387020)
* Thu Mar  8 2018 lbeltrame@kde.org
- Update to 17.12.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.3.php
- Changes since 17.12.2:
  * None
* Wed Feb  7 2018 lbeltrame@kde.org
- Update to 17.12.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.2.php
- Changes since 17.12.1:
  * ffmpeg: add checks in metadata to string conversion
* Thu Jan 11 2018 lbeltrame@kde.org
- Update to 17.12.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.1.php
- Changes since 17.12.0:
  * Revert "Fix Settings dialog resizes itself issue"
* Tue Jan  9 2018 wbauer@tmo.at
- Add fix-build-with-older-kio.patch to make it build again on
  standard Leap 42.x.
* Sat Dec  9 2017 lbeltrame@kde.org
- Update to 17.12.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12.0.php
- Changes since 17.11.90:
  * None
* Sat Dec  2 2017 lbeltrame@kde.org
- Update to 17.11.90
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-rc.php
- Changes since 17.11.80:
  * None
* Mon Nov 20 2017 lbeltrame@kde.org
- Update to 17.11.80
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.12-beta.php
- Changes since 17.08.3:
  * Too many changes to list here
- Dropped patches, now upstream:
  * Add-forceCheck-for-ManualCheckSystem.patch
  * Fix-creating-DVD-video-image.patch
  * Add-readCheckSystemConfig.patch
* Thu Nov  9 2017 lbeltrame@kde.org
- Update to 17.08.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.3.php
- Changes since 17.08.2:
  * None
* Tue Oct 17 2017 wbauer@tmo.at
- Enable MP3 support in general by default, libmad and lame
  have been released as update for Leap 42.2 and 42.3 too
* Mon Oct 16 2017 lbeltrame@kde.org
- Update to 17.08.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.2.php
- Changes since 17.08.1:
  * None
* Mon Sep 11 2017 jengelh@inai.de
- Ensure description is neutral.
* Thu Sep  7 2017 lbeltrame@kde.org
- Update to 17.08.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.08.1.php
- Changes since 17.08.0:
  * None
* Wed Aug 30 2017 wbauer@tmo.at
- Enable MP3 support in Factory/Tumbleweed, libmad and lame are
  part of the distribution now
* Sat Aug 12 2017 wbauer@tmo.at
- Add Fix-creating-DVD-video-image.patch to fix creating Video DVDs
  (boo#1051338, kde#383011)
* Fri Aug 11 2017 christophe@krop.fr
- Update to KDE Applications 17.08.0
  * New feature release
  * https://www.kde.org/announcements/announce-applications-17.08.0.php
- Changes since 17.04.3 :
- Too many changes to list here
* Sat Aug  5 2017 christophe@krop.fr
- Update to KDE Applications 17.07.90
  * KDE Applications 17.07.90
  * https://www.kde.org/announcements/announce-applications-17.08-rc.php
- Drop Re-enable-transcode-support.patch (merged upstream)
- Drop Fix-do-not-show-again.patch (merged upstream)
* Wed Aug  2 2017 wbauer@tmo.at
- Add Add-forceCheck-for-ManualCheckSystem.patch to make the manual
  system check work again after the previous fix
* Tue Aug  1 2017 wbauer@tmo.at
- Add upstream patches to not show the system configuration
  problems dialog if disabled (kde#381368, boo#1051368)
  * Fix-do-not-show-again.patch
  * Add-readCheckSystemConfig.patch
* Wed Jul 26 2017 wbauer@tmo.at
- Add Don-t-suggest-to-install-libburn.patch to not suggest to the
  user to install libburn on startup. The message is actually
  misleading as k3b would actually use cdrskin which is packaged
  separately in openSUSE. But let's stick to prefer the proven
  cdrecord for now, people can still install cdrskin if they'd
  prefer to use it. (boo#1050715)
* Sat Jul 15 2017 lbeltrame@kde.org
- Update to 17.04.3
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.3.php
- Changes since 17.04.2:
  * None
* Mon Jun 12 2017 wbauer@tmo.at
- Add Re-enable-transcode-support.patch to add back transcode
  support to rip DVDs, Packman's version seems to work fine
  (kde#381131)
* Wed Jun  7 2017 lbeltrame@kde.org
- Update to 17.04.2
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.2.php
- Changes since 17.04.1:
  * None
* Tue May 23 2017 wbauer@tmo.at
- Only use the %%kf5_find_htmldocs macro on Leap 42.3 and higher,
  this should fix the build for 42.2 on Packman
* Wed May 17 2017 lbeltrame@kde.org
- Update to 17.04.1
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.1.php
- Changes since 17.04.0:
  * None
* Sun Apr 16 2017 lbeltrame@kde.org
- Update to 17.04.0
  * New feature release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04.0.php
- Changes since 17.03.90:
  * tests: Use QTEST_GUILESS_MAIN
* Wed Apr 12 2017 lbeltrame@kde.org
- Update to 17.03.90
  * New bugfix release
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-rc.php
- Changes since 17.03.80:
  * None
* Sun Mar 26 2017 lbeltrame@kde.org
- Update to 17.03.80
  * New feature release (KF5 based)
  * For more details please see:
  * https://www.kde.org/announcements/announce-applications-17.04-beta.php
- Changes since 2.0.3:
  * Too many changes to list here
- Dropped patches (upstreamed or no longer applicable to the KF5 version):
  * building-docs-once-is-enough.patch
  * initial-preference.diff
  * fix-dvd-transcoding.patch
  * k3b-ffmpeg3.patch
  * k3b-2.0.3-gcc6.patch
* Thu Dec  8 2016 fabian@ritter-vogt.de
- Revert kde4_runtime_requires change
* Wed Nov 30 2016 wbauer@tmo.at
- Obsolete k3b-codecs, the additional codecs are part of the main
  package now
* Tue Nov 29 2016 olaf@aepfle.de
- Restore conditionals for lame and libmad
* Tue Nov 29 2016 olaf@aepfle.de
- Expand macro kde4_runtime_requires only when its available
  to fix quilt setup
* Mon Jul 25 2016 olaf@aepfle.de
- Build with ffmpeg unconditional
- Remove unused ffmpeg pkgs
* Sat Jun 25 2016 davejplater@gmail.com
- Add k3b-ffmpeg3.patch from arch linux to fix build against
  ffmpeg 3x
* Wed May 25 2016 dimstar@opensuse.org
- Add k3b-2.0.3-gcc6.patch: Fix build with GCC 6. Patch copied from
  Gentoo.
* Mon Jan  4 2016 tittiatcoke@gmail.com
- Use the internal ffmpeg package to build.
  This would prevent to swap k3b with the one from packman to have
  mp3 support
* Thu Dec 24 2015 alarrosa@suse.com
- Added Requires(post/un) hicolor-icon-theme since it's needed by
  %%icon_theme_cache_post/un
* Wed Dec 23 2015 alarrosa@suse.com
- Updated initial-preference.diff so it applies without any offset
* Fri Nov  6 2015 tchvatal@suse.com
- Cleanup with spec-cleaner
- Use buildorig syntax instead of with/without conditionals
- Remove icons magic that is not needed anymore
* Fri Oct 30 2015 wbauer@tmo.at
- Add fix-dvd-transcoding.patch: Fix transcoding of DVD titles
  (kde#350403)
* Sun Oct 11 2015 hrvoje.senjan@gmail.com
- Added building-docs-once-is-enough.patch: Fix build when CMP002
  policy is set to NEW
* Fri Jun  5 2015 wbauer@tmo.at
- fix solid actions symlinks
* Sun May 17 2015 hrvoje.senjan@gmail.com
- Symlink solid actions into place known to Plasma 5
* Tue Mar 31 2015 wbauer@tmo.at
- Remove unnecessary Requires: cdparanoia-devel, this was added
  as a workaround for a bug in the 2.0.80git version (kde#328769),
  but this is long fixed and never was present in the stable 2.0
  branch anyway
* Tue Nov 11 2014 Led <ledest@gmail.com>
- fix bashisms in post/postun scripts
* Tue Nov  4 2014 hrvoje.senjan@gmail.com
- Drop ImageMagick BuildRequires together with adjusting png's as
  they are fixed upstream
- Drop version checks for ancient openSUSE versions
* Tue Nov  4 2014 hrvoje.senjan@gmail.com
- Update to 2.0.3:
  * Fixed crash in MetaItemModel on submodel item removal
  * Fixed Solid predicates for AudioCd and VideoDvd media.
    kde#265819
  * Set error status when CDDB query fails.
  * Prefer growisofs to wodim for DVD/BluRay burning.
  * Fixed improper track number in CDDB track edit window title.
    kde#276681
  * Fixed crash on detecting writing speeds. kde#272427
  * Fix problem with HL-DT-ST BH10LS30. kde#268307
  * Fixed compilation with new FFMPEG. kde#274817 kde#300731
  * Allow using CD-R90 and CD-R99 media to full capacity.
    kde#276002
  * Refactor the FreeBSD SCSI/CAM interface.
  * Fix crash on dvd ripping
  * fix sox detection with sox >= 14.4.0. kde#301544
  * Support more media types. kde#261652
  * Fix file system detection. kde#325616 kde#262607
  * Surround output filename for transcode with double quotes.
    kde#326097
  * Fix FILE name and type detection for cue sheet images.
    kde#337201
  * Rip audio tracks in ascending numerical order.
    kde#319678
  * Upstream patches from NetBSD.
  * Make paranoia lib detection better.
  * Don't preview if called process failed. kde#268680
  * Fix Crash while remove songs in "Mixed mode CD proyect".
    kde#323117
  * Use QElapsedTimer to calculate remaining time.
    kde#330239 kde#315463
  * Fix crash in lsof wrapper. kde#340515
- Drop patches merged upstream:
  k3b-prefer-growisofs-to-wodim-for-DVD-burning.patch,
  k3b-fixed-crash-on-detecting-writing-speeds.patch,
  k3b-fixed-solid-predicates.patch,
  k3b-2.0.2-ffmpeg011.patch,
  k3b-short-trackinfo.patch,
  k3b-increase-tolerance.patch,
  add_mimetypes_bnc661777.diff,
  k3b-fixed-improper-track-number-in-CDDB-track-edit-window-title.patch,
  k3b-set-error-status-when-CDDB-query-fails.patch and
  k3b-dont-count-used-capacity-twice.patch
* Thu Aug 14 2014 hrvoje.senjan@gmail.com
- Use kde4-macros for filelists, k3b uses kdelibs4 buildsystem
* Sun Jun 22 2014 ctrippe@opensuse.org
- Add Requires: cdparanoia-devel to make copying of a CD work
  (kde#328769)
* Tue Feb 19 2013 dmitry_r@opensuse.org
- Replace recommended package dependencies with file dependencies
* Mon Dec 17 2012 hrvoje.senjan@gmail.com
- Add various bugfixes from upstream 2.0 branch
  * k3b-dont-count-used-capacity-twice.patch (kde#276002)
  * k3b-fixed-crash-on-detecting-writing-speeds.patch (kde#272427)
  * k3b-fixed-improper-track-number-in-CDDB-track-edit-window-title.patch (kde#276681)
  * k3b-fixed-solid-predicates.patch (kde#265819)
  * k3b-increase-tolerance.patch (kde#276002)
  * k3b-prefer-growisofs-to-wodim-for-DVD-burning.patch
  * k3b-set-error-status-when-CDDB-query-fails.patch
* Wed Jul 25 2012 reddwarf@opensuse.org
- Fix build with ffmpeg 0.11. Took from Packman.
* Sun Apr 15 2012 dmueller@suse.com
- update buildrequires (taglib->libtag)
* Wed Aug 31 2011 idonmez@suse.com
- Add k3b-short-trackinfo.patch: Too short track info dataLen
  returned at least on HL-DT-ST BH10LS30 , bko #268307
* Sun Aug 14 2011 reddwarf@opensuse.org
- Add k3b-2.0.2-ffmpeg08.patch to allow it to compile against the
  new ffmpeg versions.
* Wed Apr 27 2011 asterios.dramis@gmail.com
- Spec file updates:
  * Changes based on rpmdevtools templates and spec-cleaner run.
  * Cleanup in Buildrequires: entries.
  * Added /usr/bin/readcd in Requires:.
  * Recommend normalize, sox, transcode and vcdimager packages.
  * Fixed rpmlint warning for Provides/Obsoletes of kde4-k3b.
  * Updates in Url:, Summary: and %%description.
  * Added description for the patches based on openSUSE Patches Guidelines.
  * Changed k3b-devel Group: to "Development/Libraries/C and C++".
  * Compile the package with "-fno-strict-aliasing".
  * Added "AudioVideo" to the Categories entry of k3b.desktop file.
  * Remove some more locales for openSUSE < 11.4.
  * Moved english help files in the main package.
  * Updates in %%files section (also removed support for openSUSE < 11.2).
  * Minor other updates.
- Fixed some rpmlint warnings.
* Tue Apr 19 2011 tittiatcoke@gmail.com
- Fix type in spec-file
* Thu Feb 17 2011 wstephenson@novell.com
- call update-mime-database in pre/post install scripts
* Fri Jan 28 2011 embar@super.lt
- Since using option -DK3B_ENABLE_HAL_SUPPORT=OFF, HAL is not required
* Sun Jan 16 2011 tittiatcoke@gmail.com
- Update to 2.0.2:
  * Changes:
  - Added K3B_ENABLE_HAL_SUPPORT option to the build configuration.
    It allows to disable any direct calls to HAL (bko#253388)
  - Using Oxygen sounds for events (bko#242395)
  * Bugfixes:
  - Crash on start when checking device capabilities (bko#246822)
  - Search paths on "Programs" options are not saved (bko#248648)
  - Crash on generation of DVD previews in DVD ripping list
    (bko#249941, bko#253639)
  - Crash on closing dialog after succesful audio CD ripping
    (bko#241630)
  - Crash on device detection (bko#249371)
  - Crash when showing settings window (bko#238819)
  - Fixed playlist sort order (bko#249395)
  - Show K3b also in "System" category in KDE launch menus
    (bko#250749)
  - Crash when multiple instances start at the same time
    (bko#253794)
  - Crash after track splitting (bko#261188)
  - Inline editing of tracks in CD ripping view no longer works
    (bko#250600)
* Thu Dec 30 2010 ctrippe@gmx.net
- Add a few mimetypes to the desktop file for better integration in
  GNOME (bnc#661777)
* Sun Nov 28 2010 jslaby@suse.de
- Device detection crash fix
* Fri Oct 22 2010 abrouwers@gmail.com
- Fix crash entering settings dialog with qt47 (upstream
  http://websvn.kde.org/?revision=1186323&view=revision)
* Tue Aug 31 2010 aj@suse.de
- Recommend instead of require lang package since it's not mandatory.
* Tue Aug 17 2010 beineri@opensuse.org
- update to 2.0.1: several bugfixes
* Fri Aug 13 2010 vuntz@opensuse.org
- Drop unneeded libnjb-devel BuildRequires.
* Tue Jun 29 2010 tittiatcoke@gmail.com
- Update to final version of 2.0.0:
  * fixed german translation, no code change
* Fri Jun 18 2010 llunak@novell.com
- HAL is required for K3B to work (bnc#613898)
- make the default handler for .iso files instead of Ark
* Thu Jun 17 2010 wstephenson@novell.com
- Update to 1.93 (2.0rc4)
  Changes:
  * Moved K3b Handbook to http://userbase.kde.org/K3b
  * Improved checking/unchecking items using Space key. Previously to do that the current item had to be in first column.
  Bugfixes:
  * Cannot choose between cdrecord when both cdrecord and wodim are installed (bko#239861)
  * Crash when files have been removed right before burning the project (bko#240398)
  * Crash when moving a file into a directory with Shift key pressed (bko#239075)
  * Invalid parameter to cdrecord for non-integer burning speed (bko#240310)
  * Crash when burning CD Audio project with tracks from another CD (bko#240450)
  * Crash when turning off the drive (bko#235743)
  * Crash when importing previous session (bko#235734)
  * Various crashes during manipulation of eMovix project view
  * Hang before verification (bko#156684)
  * Crash when "Waiting for medium" dialog is closed (bko#232148)
* Wed May 26 2010 llunak@novell.com
- fix build for <= 11.2
* Tue May 25 2010 wstephenson@novell.com
- update to 1.92 (2.0rc3)
  + Bugfixes:
  * In some cases medium doesn’t get accepted for multisession burning (bko#230742)
  * Data files in VCD ripping view are not listed
  * Show “Modify Permissions” button in System Problem Dialog only when it makes sense (bko#230706)
  * Crash after “Cancel” was clicked while adding audio files to AudioCD project (bko#231348)
  * Error window at the start when a place on the left pane is not accessible (bko#230194)
  * Incorrect minimum size of welcome widget (bko#231939)
  * Hangs while ripping AudioCD with data tracks (bko#231174)
  * Crash when auto-removing non-existing files from a project before the burning (bko#236005)
  * Empty Blu-ray medium not detected properly (bko#236069)
  * eMovix project cannot be burned (bko#236823)
  * M3U playlist not read properly (bko#237654)
  * K3b overwrites iso ignoring user choice on dvd copy with option “only create image” checked (bko#185251)
  * Compilation fails with FFmpeg version SVN-r23001 (bko#236036)
  * Crash when waiting for reload the medium
* Wed Mar 17 2010 coolo@novell.com
- fix file list
* Wed Mar 10 2010 tittiatcoke@gmail.com
- update to 1.91 (2.0rc2)
  + New:
  * K3bSetup ported to KAuth framework
  + Bugfixes:
  * Crash on start of Audio Ripping Dialog (bko#226595)
  * Incorrect ordering of files added to Audio Project (bko#224649)
  * Too wide Image burn Dialog when file path was long (bko#225735)
  * Crash when creating image files for AudioCD project (bko#219500)
  * Crash when manipulating VCD project items (bko#227855)
  * Mixed-up metadata in files created with external encoder (bko#227927)
  * Cannot edit time values in "Split Audio Track" and "Edit Audio Track"
    dialog (bko#229042)
  * Empty Bly-ray mediam not detected properly (bko#227339, bko#229039)
  * Crash during splitting/editing audio tracks
  * Entry fields doesn't work in burn window when "Only Create Image"
    option is checked (bko#220970)
  * Layout issues in settings window (bko#227733)
* Tue Feb  9 2010 tittiatcoke@gmail.com
- update to 1.70 (2.0 Beta 1)
  Changes:
  * Added Blu-ray support
  * Added "Options" button to file browser toolbar with view options menu
    (e.g. "Show Hidden Files") (bko#196992)
  * Image and project files can be opened directly from K3b file browser
  * Using Oxygen icons (many thanks for Oxygen Team!)
  Bugfixes:
  * Fixed visual glitch when panes are in "locked" state.
    Patch by Craig Drummond <craig@kde.org>
  * Fixed hang up when "Create Image" option is checked (bko#217301)
  * "Hide main window while writing" option is working again
  * "Show OSD progress" option is working again
  * Improved message when ISO with incorrect size is detected (bko#216812)
  * Improved consistency: K3b now uses system-wide
    Positive/Neutral/Negative colors where possible instead of
    hard-coded green/yellow/red
  * Fixed incorrect default value "4gb." in "Custom Size" dialog (bko#215539)
  * Fixed usability issues with project size menu:
    "Custom..." and "From Medium..." menu entries are non-checkable now (bko#215539)
  * Show correct message at the end of CD-RW erasing (bko#207972)
  * Fixed issue with too small configuration dialog for external encoder (bko#218613)
  * Track number is now stored in ripped MP3 files when using lame (bko#218614)
  * "Defaults" button in encoder configuration dialogs are working now
  * Fixed usability problems of audio project list
  * Fixed linking error on Windows
  * Fixed crash during verification process (bko#219962)
  * Fixed crash in external encoder plug-in
  * Brought back SOX encoder configuration dialog
  * Fixed checking free space in temporary folder
  * Fixed videodvd:/ KIO slave
  * Fixed hang-up for mixed projects after reloading medium for verification
  * Converting audio tracks from audio project is working again
  * Fixed burning bootable discs
  * Custom widgets are now properly rendered for Right-to-Left languages
  * Progress bar in image writing dialog is shown again
  * Fixed crash while analysing invalid medium (bko#223362)
  * Acquire lock also on storage interface. This prevents HAL from
    polling medium during burning which might disrupt burning process.
  * Fixed bug in external programs detection (bko#221638)
  * Improved usability: don't show popups when clicking on DVD, VCD or
    audio discs. Added appriopriate actions on toolbars instead.
  * Fixed crash while analysing invalid medium (bko#195436)
* Sat Nov 28 2009 tittiatcoke@gmail.com
- update to 1.69 Alpha 4: Even more bugfixes
* Sat Oct 17 2009 beineri@opensuse.org
- update to 1.68 Alpha 3: many bugfixes
- updated translations from SVN
* Sun Oct  4 2009 beineri@opensuse.org
- updated translations from SVN
* Tue Aug 11 2009 beineri@opensuse.org
- update to r1009369, add documentation & translations (bnc#529600)
* Thu Jul 30 2009 beineri@opensuse.org
- apply trunk diff (r1004480) when building on 11.2
* Thu Jul 23 2009 beineri@opensuse.org
- apply trunk diff (r1001450) when building on 11.2
* Wed May 27 2009 beineri@opensuse.org
- update to 1.66 Alpha 2: many bugfixes
* Sun May  3 2009 cmorve69@yahoo.es
- Add support for Musepack/MPC
- Disable K3BSetup
* Thu Apr 23 2009 beineri@opensuse.org
- rename to k3b, update to 1.65.0 Alpha
* Sat Mar 21 2009 beineri@opensuse.org
- update to 4.2.1.svn942189
* Wed Feb 25 2009 stbinner@suse.de
- update to 4.2.0.svn931376
* Wed Feb 18 2009 stbinner@suse.de
- update to 4.2.0.svn927728
* Fri Jan 23 2009 stbinner@suse.de
- update to 4.1.4.svn915827
* Wed Jan  7 2009 stbinner@suse.de
- update to 4.1.4.svn907132
* Tue Dec 16 2008 stbinner@suse.de
- update to 4.1.3.svn897517
* Sat Nov 22 2008 stbinner@suse.de
- update to 4.1.3.svn887510
* Fri Nov  7 2008 stbinner@suse.de
- update to 4.1.3.svn881374
* Sat Sep 13 2008 stbinner@suse.de
- update to 4.1.1.svn860449
* Fri Aug 22 2008 stbinner@suse.de
- update to 4.1.0.svn851044
* Fri Jul 25 2008 stbinner@suse.de
- update to 4.1.0.svn837567
* Wed Jul 16 2008 stbinner@suse.de
- update to 4.0.98.svn833153
* Fri Jun 27 2008 dmueller@suse.de
- update to 4.0.84.svn825098
* Tue Jun  3 2008 dmueller@suse.de
- update to 4.0.81.svn816194
* Thu May 15 2008 dmueller@suse.de
- update to 4.0.74.svn808129
* Wed May  7 2008 dmueller@suse.de
- update to 4.0.73.svn805196
* Thu Apr 24 2008 dmueller@suse.de
- update to 4.0.71.svn800684
* Fri Apr 18 2008 dmueller@suse.de
- update to 4.0.69.svn798537
* Wed Apr  2 2008 dmueller@suse.de
- update to 4.0.68.svn792936
* Thu Feb 14 2008 dmueller@suse.de
- update to 4.0.62.svn775117
* Wed Nov 28 2007 dmueller@suse.de
- update to 3.96.0.svn742626
* Thu Nov  1 2007 dmueller@suse.de
- update to 3.95.0.svn731749
